@@ -4,11 +4,11 @@ from __future__ import annotations
 import requests
 
 # GET one object
-def rget(host: str = "localhost", port: int = 8080, db: int = 0, key: str = "") -> any:
+def rget(key: str, host: str = "localhost", port: int = 8080, db: int = 0) -> any:
     return rsend("get", host, port, db, key)
 
 # POST one object
-def rset(host: str = "localhost", port: int = 8080, db: int = 0, key: str = "", value: str = ""):
+def rset(key: str, value: str, host: str = "localhost", port: int = 8080, db: int = 0):
     return rsend("set", host, port, db, key, value)
 
 # GET all keys
@@ -16,7 +16,7 @@ def rkeys(host: str = "localhost", port: int = 8080, db: int = 0) -> list[str]:
     return rsend("get", host, port, db)
 
 # Send a request
-def rsend(method: str = "get", host: str = "localhost", port: int = 8080, db: int = 0, key: str = "", value: str = ""):
+def rsend(method: str, key: str, value: str, host: str = "localhost", port: int = 8080, db: int = 0):
     params = {}
     if key != "":
         params.update({"key": key})
